package com.tongran.rocketmq.mapper;

import java.util.List;
import com.tongran.rocketmq.domain.RmFrpcConfigManage;

/**
 * FRPC配置管理Mapper接口
 * 
 * @author tongran
 * @date 2025-12-19
 */
public interface RmFrpcConfigManageMapper 
{
    /**
     * 查询FRPC配置管理
     * 
     * @param id FRPC配置管理主键
     * @return FRPC配置管理
     */
    public RmFrpcConfigManage selectRmFrpcConfigManageById(Long id);

    /**
     * 查询FRPC配置管理列表
     * 
     * @param rmFrpcConfigManage FRPC配置管理
     * @return FRPC配置管理集合
     */
    public List<RmFrpcConfigManage> selectRmFrpcConfigManageList(RmFrpcConfigManage rmFrpcConfigManage);

    /**
     * 新增FRPC配置管理
     * 
     * @param rmFrpcConfigManage FRPC配置管理
     * @return 结果
     */
    public int insertRmFrpcConfigManage(RmFrpcConfigManage rmFrpcConfigManage);

    /**
     * 修改FRPC配置管理
     * 
     * @param rmFrpcConfigManage FRPC配置管理
     * @return 结果
     */
    public int updateRmFrpcConfigManage(RmFrpcConfigManage rmFrpcConfigManage);

    /**
     * 删除FRPC配置管理
     * 
     * @param id FRPC配置管理主键
     * @return 结果
     */
    public int deleteRmFrpcConfigManageById(Long id);

    /**
     * 批量删除FRPC配置管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRmFrpcConfigManageByIds(Long[] ids);
}
